@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Create network transition chord progressions
 
-our $VERSION = '0.0306';
+our $VERSION = '0.0400';
 
 use Carp qw(croak);
 use Data::Dumper::Compact qw(ddc);
@@ -36,7 +36,7 @@ has net => (
 );
 
 
-has chords => (
+has chord_map => (
     is      => 'ro',
     isa     => sub { die "$_[0] is not a arrayref" unless ref $_[0] eq 'ARRAY' },
     default => sub { ['', 'm', 'm', '', '', 'm'] },
@@ -138,8 +138,8 @@ has verbose => (
 sub generate {
     my ($self) = @_;
 
-    croak 'chords length must equal number of net keys'
-        unless @{ $self->chords } == keys %{ $self->net };
+    croak 'chord_map length must equal number of net keys'
+        unless @{ $self->chord_map } == keys %{ $self->net };
 
     print 'Graph: ' . $self->graph, "\n" if $self->verbose;
 
@@ -152,11 +152,11 @@ sub generate {
     }
     print "Progression: @progression\n" if $self->verbose;
 
-    my @chords = @{ $self->chords };
+    my @chord_map = @{ $self->chord_map };
 
     if ($self->substitute) {
         my $i = 0;
-        for my $chord (@chords) {
+        for my $chord (@chord_map) {
             my $substitute = $self->sub_cond->() ? $self->substitution($chord) : $chord;
             if ($substitute eq $chord && $i < @progression && $self->sub_cond->()) {
                 $progression[$i] .= 't'; # Indicate that we should tritone substitute
@@ -166,16 +166,17 @@ sub generate {
         }
     }
 
-    my @phrase = map { $self->_tt_sub(\@chords, $_) } @progression;
+    my @phrase = map { $self->_tt_sub(\@chord_map, $_) } @progression;
     print "Phrase: @phrase\n" if $self->verbose;
 
-    # Add octaves to the chord notes
+    # Add octaves to the chords
     my $mcn = Music::Chord::Note->new;
-    my @notes;
+    my @chords;
     for my $chord (@phrase) {
         my @chord = $mcn->chord_with_octave($chord, $self->octave);
-        push @notes, \@chord;
+        push @chords, \@chord;
     }
+
     if ($self->flat) {
         my %equiv = (
             'C#' => 'Db',
@@ -186,15 +187,16 @@ sub generate {
             'A#' => 'Bb',
             'B#' => 'C',
         );
-        for my $chord (@notes) {
+        for my $chord (@chords) {
             for my $note (@$chord) {
                 $note =~ s/^([A-G]#)(\d+)$/$equiv{$1}$2/ if $note =~ /#/;
             }
         }
     }
-    print 'Notes: ', ddc(\@notes) if $self->verbose;
 
-    return \@notes;
+    print 'Notes: ', ddc(\@chords) if $self->verbose;
+
+    return \@chords;
 }
 
 sub _next_successor {
@@ -238,7 +240,7 @@ sub _full_keys {
 }
 
 sub _tt_sub {
-    my ($self, $chords, $n) = @_;
+    my ($self, $chord_map, $n) = @_;
 
     my $note;
 
@@ -256,7 +258,7 @@ sub _tt_sub {
         $note = $self->scale->[$n - 1];
     }
 
-    return $note . $chords->[$n - 1];
+    return $note . $chord_map->[$n - 1];
 }
 
 
@@ -308,7 +310,7 @@ Music::Chord::Progression - Create network transition chord progressions
 
 =head1 VERSION
 
-version 0.0306
+version 0.0400
 
 =head1 SYNOPSIS
 
@@ -378,7 +380,7 @@ chosen here:
     6 => [qw( 2 4 )],
     7 => [qw( 1 4 )] }
 
-=head2 chords
+=head2 chord_map
 
 The chord names of each scale position.
 
@@ -491,7 +493,7 @@ Show the B<generate> and B<substitute> progress.
   $prog = Music::Chord::Progression->new( # Override the defaults
     max        => 4,
     net        => { 1 => [...], ... 6 => [...] },
-    chords     => ['m','','m','m','',''],
+    chord_map  => ['m','','m','m','',''],
     scale_name => 'minor',
     scale_note => 'A',
     octave     => 5,
